require 'logging'
require 'terminal'

class Session
	include Logging
	
	# build options
    attr_accessor :agent_name, :is_build_agent, :framework_version, :configuration, :environment

	# directories
	attr_accessor :working_dir, :tools_dir, :output_dir

	attr_accessor :globals_file, :tokens_pattern, :tools_download_uri

	def initialize(&block)
		block ||= proc {}

		set_defaults
		instance_eval(&block)
		
		correct_windows_paths
		print_session_info
		create_tasks
	end 

	private

	def set_defaults
		@agent_name = ENV['COMPUTERNAME']

        @framework_version = 'v4.0.30319'
		@configuration = 'Release'
		@environment = ENV['ENVIRONMENT'].nil? ? 'local' : ENV['ENVIRONMENT']
        
		@working_dir = Dir.getwd
        @tools_dir = File.join(@working_dir, '../tools')
        @output_dir = File.join(@working_dir, '/_output')
		
		@globals_file = './Globals.config'
		@tokens_pattern = '*.master.{^cs}'
		@tools_download_uri = 'https://bitbucket.org/robertbeal/rakeoff/downloads/tools.zip'		
	end

	def create_tasks
		tasks = DefaultTasks.new(self, Tools.new)
		tasks.setup
	end

	def correct_windows_paths
		@working_dir.gsub!('\\', '/')
        @tools_dir.gsub!('\\', '/')
        @output_dir.gsub!('\\', '/')
	end

    def print_session_info
		print_heading 'Build Info'

		puts "Agent               = #{@agent_name}"
		puts ''

		puts "Building For        = #{@environment}"
		puts "Framework Version   = #{@framework_version}"		
		puts "Configuration       = #{@configuration}"
		puts "Token File Pattern  = #{@tokens_pattern}"
		puts "Global Tokens File  = #{@globals_file}"
		puts ''

		puts "Output Directory    = #{@output_dir}"
		puts "Tools Directory     = #{@tools_dir}"
    end

end
