require 'fileutils'
require 'terminal'

class NUnit

	attr_accessor :assemblies

	def initialize(session)
		@session = session
	end

    def execute(pattern)
		print_heading("Tests - #{pattern}")
		
		projects = get_test_projects_for(pattern)

		if(!projects.empty?)
			project_list = projects.join(' ').strip

			if(ENV["NUNIT_RUNNER"].nil?)
				mkdir_p File.join(@session.output_dir, '/test-reports')
				nunit = Dir.glob(File.join(@session.tools_dir, '/**/nunit-console.exe')).last

			    sh "#{nunit} #{project_list} /xml=#{File.join(@session.output_dir, '/test-reports/nunit.xml')}"
			else
			    sh "#{ENV["NUNIT_RUNNER"]} v4.0 x86 NUnit-2.5.3 #{project_list}"
			end	
        end
    end    

	private

    def get_test_projects_for(pattern)
        projects = Dir.glob(pattern, File::FNM_CASEFOLD).reject {|f| File.directory?(f) }		
		puts "No test projects found matching pattern #{pattern}".yellow if(projects.length == 0)
		return projects	
    end
end
